use strict;
use Test::More;

use_ok $_ for qw(
    Test::JsonAPI::Autodoc
    Test::JsonAPI::Autodoc::Markdown
    Test::JsonAPI::Autodoc::Path
    Test::JsonAPI::Autodoc::Request
    Test::JsonAPI::Autodoc::Response
);

done_testing;

